@@ -11,8 +11,8 @@ import re
 
 import unidecode
 
-from .. import constants
-from ..utils import cached_property, fs, signal
+from .. import constants, utils
+from ..utils import cached_property
 
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
@@ -64,7 +64,7 @@ class JobBase(abc.ABC):
         This directory is guaranteed to exist.
         """
         if self._home_directory and not os.path.exists(self._home_directory):
-            fs.mkdir(self._home_directory)
+            utils.fs.mkdir(self._home_directory)
         return self._home_directory
 
     @cached_property
@@ -75,7 +75,7 @@ class JobBase(abc.ABC):
         This directory is guaranteed to exist.
         """
         if not os.path.exists(self._cache_directory):
-            fs.mkdir(self._cache_directory)
+            utils.fs.mkdir(self._cache_directory)
         return self._cache_directory
 
     @property
@@ -102,7 +102,10 @@ class JobBase(abc.ABC):
         """
         return (
             self._autostart
-            and all(prejob.is_finished for prejob in self.prejobs)
+            and all(
+                (prejob.is_finished or not prejob.is_enabled)
+                for prejob in self.prejobs
+            )
         )
 
     @property
@@ -143,6 +146,11 @@ class JobBase(abc.ABC):
         The following signals are added by the base class. Subclasses can add
         their own signals.
 
+        ``executed``
+            Emitted after :meth:`execute` was called. When output is read from
+            cache, this signal is not emitted. Registered callbacks get the job
+            instance as a positional argument.
+
         ``finished``
             Emitted when :meth:`finish` is called or when output is read from
             cache. Registered callbacks get the job instance as a positional
@@ -172,7 +180,8 @@ class JobBase(abc.ABC):
         """
         Sequence of prerequisite :class:`jobs <upsies.jobs.base.JobBase>`
 
-        :attr:`autostart` stays `False` until all `prejobs` have finished.
+        :attr:`autostart` stays `False` until all `prejobs` are either finished
+        or :attr:`disabled <is_enabled>`
         """
         return self._prejobs
 
@@ -200,7 +209,7 @@ class JobBase(abc.ABC):
         self._finished_event = asyncio.Event()
         self.prejobs = prejobs
 
-        self._signal = signal.Signal('output', 'info', 'warning', 'error', 'finished')
+        self._signal = utils.signal.Signal('output', 'info', 'warning', 'error', 'executed', 'finished')
         self._signal.register('output', lambda output: self._output.append(str(output)))
         self._signal.register('warning', lambda warning: self._warnings.append(warning))
         self._signal.register('error', lambda error: self._errors.append(error))
@@ -255,11 +264,15 @@ class JobBase(abc.ABC):
                 raise
 
             if cache_was_read:
+                _log.debug('%s: Using cached output', self.name)
                 self.finish()
             else:
-                _log.debug('Executing job: %s', self.name)
+                _log.debug('%s: Executing', self.name)
                 self._is_executed = True
                 self.execute()
+                self.signal.emit('executed', self)
+        else:
+            _log.debug('%s: Disabled', self.name)
 
     @property
     def is_started(self):
@@ -305,6 +318,7 @@ class JobBase(abc.ABC):
         if not self.is_finished:
             for task in self._tasks:
                 if not task.done():
+                    _log.debug('%s: Cancelling %r', self.name, task)
                     task.cancel()
             self._finished_event.set()
             self.signal.emit('finished', self)
@@ -415,15 +429,16 @@ class JobBase(abc.ABC):
         """Exception passed to :meth:`exception`"""
         return self._exception
 
-    def add_task(self, coro, callback=None, finish_when_done=False):
+    def attach_task(self, coro, callback=None, finish_when_done=False):
         """
-        Run asynchronous coroutine in a background task and return immediately
+        Run asynchronous coroutine in background task and return immediately
 
-        This method should be used to call coroutine functions and other
-        awaitables in a synchronous context.
+        This method is a wrapper around :func:`~.utils.run_task` that finishes
+        the job when `coro` returns or raises.
 
         Any exceptions from `coro` are passed to :meth:`exception`.
-        :class:`asyncio.CancelledError` is ignored.
+
+        `coro` is automatically and silently cancelled by :meth:`finish`.
 
         :param coro: Any awaitable object
         :param callback: Callable that is called with the return value of `coro`
@@ -432,43 +447,32 @@ class JobBase(abc.ABC):
 
         :return: :class:`asyncio.Task` instance
         """
+        if self.is_finished:
+            raise RuntimeError(f'Job is already finished: {self.name}')
 
-        async def wrapper(coro, callback, finish_when_done):
+        def callback_(result):
             try:
-                result = await asyncio.ensure_future(coro)
-            except asyncio.CancelledError:
-                pass
-            except BaseException as e:
-                _log.debug('%s: Caught %r from %r', self.name, e, coro)
-                self.exception(e)
-            else:
-                if callback:
-                    try:
-                        callback(result)
-                    except BaseException as e:
-                        self.exception(e)
-                return result
+                if isinstance(result, BaseException):
+                    _log.debug('%s: Handling exception from %r: %r', self.name, coro, result)
+                    self.exception(result)
+                else:
+                    if callback:
+                        try:
+                            callback(result)
+                        except BaseException as e:
+                            _log.debug('%s: Handling exception from callback %r: %r', self.name, callback, result)
+                            self.exception(e)
+                    return result
             finally:
                 if finish_when_done:
-                    _log.debug('Finishing %r because of finished coro: %r', self.name, coro)
                     self.finish()
 
-        async def catch_cancelled_error(coro):
-            try:
-                return await asyncio.ensure_future(coro)
-            except asyncio.CancelledError:
-                _log.debug('%s: Cancelled: %r', self.name, coro)
-
-        wrapped = asyncio.ensure_future(
-            catch_cancelled_error(
-                wrapper(coro, callback, finish_when_done),
-            ),
-        )
-        self._tasks.append(wrapped)
-        return wrapped
+        task = utils.run_task(coro, callback=callback_)
+        self._tasks.append(task)
+        return task
 
     async def await_tasks(self):
-        """Block until all coroutines passed to :meth:`add_task` are done"""
+        """Block until all coroutines passed to :meth:`attach_task` are done"""
         for task in self._tasks:
             await task
 
@@ -562,7 +566,7 @@ class JobBase(abc.ABC):
                     cache_id_str[-int(max_len / 2 - 1):],
                 ))
             filename = f'{self.name}.{cache_id_str}.out'
-            filename = fs.sanitize_filename(filename)
+            filename = utils.fs.sanitize_filename(filename)
         return os.path.join(self.cache_directory, filename)
 
     @cached_property
