@@ -3,7 +3,7 @@ Scene release search and check
 """
 
 from .. import errors
-from ..utils import fs, scene, types
+from ..utils import fs, predbs, types
 from . import JobBase
 
 import logging  # isort:skip
@@ -32,13 +32,15 @@ class SceneSearchJob(JobBase):
         """Final segment of `content_path`"""
         return fs.basename(self._content_path)
 
-    def initialize(self, *, content_path):
+    def initialize(self, *, content_path, predb=None):
         """
         Set internal state
 
+        :param predb: :class:`~.PredbApiBase` or :class:`~.MultiPredbApi`
         :param content_path: Path to video file or directory that contains a
             video file or release name
         """
+        self._predb = predb or predbs.MultiPredbApi()
         self._content_path = content_path
         self.signal.add('search_results')
 
@@ -48,7 +50,10 @@ class SceneSearchJob(JobBase):
 
     async def _search(self):
         try:
-            results = await scene.search(self._content_path)
+            results = await self._predb.search(
+                query=self._content_path,
+                only_existing_releases=False,
+            )
         except (errors.RequestError, errors.SceneError) as e:
             self.error(e)
         else:
@@ -107,15 +112,17 @@ class SceneCheckJob(JobBase):
         """
         return self._is_scene_release
 
-    def initialize(self, *, content_path, force=None):
+    def initialize(self, *, content_path, predb=None, force=None):
         """
         Set internal state
 
+        :param predb: :class:`~.PredbApiBase` or :class:`~.MultiPredbApi`
         :param content_path: Path to video file or directory that contains a
             video file or release name
         :param bool force: Predetermined check result; `True` (is scene),
             `False` (is not scene) or `None` (autodetect)
         """
+        self._predb = predb or predbs.MultiPredbApi()
         self._content_path = content_path
         self._predetermined_result = None if force is None else bool(force)
         self._is_scene_release = None
@@ -129,9 +136,11 @@ class SceneCheckJob(JobBase):
         try:
             return await coro
         except errors.RequestError as e:
+            # Maybe service is down and we have to ask the user
             self.warn(e)
             self.signal.emit('ask_is_scene_release', types.SceneCheckResult.unknown)
         except errors.SceneError as e:
+            # Something like SceneRenamedError or SceneAbbreviatedFilenameError
             self.error(e)
 
     def execute(self):
@@ -151,16 +160,19 @@ class SceneCheckJob(JobBase):
 
     async def _verify(self):
         _log.debug('Verifying release: %r', self._content_path)
-        if await scene.is_scene_release(self._content_path) is types.SceneCheckResult.false:
+        if await self._predb.is_scene_release(self._content_path) is types.SceneCheckResult.false:
             # Try to get a true negative as fast as possible
             self.finalize(types.SceneCheckResult.false)
 
-        elif await scene.is_mixed_scene_release(self._content_path):
+        elif predbs.is_mixed_season_pack(self._content_path):
             # We don't want to prompt the user if this is a mixed release
             await self._verify_release()
 
         else:
-            results = await scene.search(self._content_path, only_existing_releases=False)
+            results = await self._predb.search(
+                query=self._content_path,
+                only_existing_releases=False,
+            )
             if self.content_stem in results:
                 # Basename of content_path without extension is existing release
                 await self._verify_release()
@@ -191,7 +203,7 @@ class SceneCheckJob(JobBase):
             self._handle_scene_check_result(types.SceneCheckResult.false)
 
     async def _verify_release(self, release_name=None):
-        is_scene_release, exceptions = await scene.verify_release(self._content_path, release_name)
+        is_scene_release, exceptions = await self._predb.verify_release(self._content_path, release_name)
         self._handle_scene_check_result(is_scene_release, exceptions)
 
     def _handle_scene_check_result(self, is_scene_release, exceptions=()):
