@@ -4,7 +4,6 @@ Query online databases like IMDb
 
 import asyncio
 import collections
-from time import monotonic as time_monotonic
 
 from .. import errors
 from ..utils import get_aioloop, webdbs
@@ -81,7 +80,7 @@ class WebDbSearchJob(JobBase):
         assert isinstance(db, webdbs.WebDbApiBase), f'Not a WebDbApiBase: {db!r}'
         self._db = db
         if not isinstance(query, webdbs.Query):
-            query = webdbs.Query.from_path(str(query))
+            query = webdbs.Query.from_any(query)
         self._query = self._db.sanitize_query(query)
         self._query.signal.register('changed', self._handle_query_changed)
         self.no_id_ok = no_id_ok
@@ -126,8 +125,9 @@ class WebDbSearchJob(JobBase):
 
     def execute(self):
         """Search for initial query"""
-        # It is important NOT to do this in initialize() because the window
-        # between initialize() and execute() is used to register callbacks.
+        # It is important NOT to do this in initialize() because the time window
+        # between initialize() and execute() is used to register callbacks. If
+        # we search before all callbacks are registered, signals are ignored.
         self.search(self.query)
 
     async def wait(self):
@@ -145,24 +145,24 @@ class WebDbSearchJob(JobBase):
         self._info_updater.cancel()
         super().finish()
 
-    def search(self, query_string):
+    def search(self, query):
         """
         Make new search request
 
         Any currently ongoing search is cancelled.
 
-        :param str query_string: Query string that is first passed through
-            :meth:`~.webdbs.Query.from_string` and then
+        :param str query: Query that is first passed through
+            :meth:`~.webdbs.Query.from_any` and then
             :meth:`~.webdbs.WebDbApiBase.sanitize_query`
         """
         if not self.is_finished:
-            new_query = self._db.sanitize_query(webdbs.Query.from_string(query_string))
-            self.query.update(new_query)
-            self._searcher.search(self.query)
             self.clear_warnings()
+            new_query = self._db.sanitize_query(webdbs.Query.from_any(query))
+            self.query.update(new_query, silent=True)
+            self._searcher.search(self.query)
+            self.signal.emit('query_updated', self.query)
 
     def _handle_query_changed(self, new_query):
-        self.signal.emit('query_updated', new_query)
         self.search(new_query)
 
     def _handle_searching_status(self, is_searching):
@@ -233,6 +233,7 @@ class _Searcher:
         self._exception_callback = exception_callback
         self._previous_search_time = 0
         self._search_task = None
+        self._current_query = None
 
     async def wait(self):
         if self._search_task:
@@ -259,16 +260,21 @@ class _Searcher:
         :param query: Query to make
         :type query: :class:`~.utils.webdbs.Query`
         """
-        if self._search_task:
-            self._search_task.cancel()
-            self._search_task = None
-        self._search_task = get_aioloop().create_task(self._search(query))
-        self._search_task.add_done_callback(self._handle_search_task)
+        if self._current_query != query:
+            if self._search_task:
+                self._search_task.cancel()
+
+            self._current_query = query.copy()
+            self._search_task = get_aioloop().create_task(self._search(query))
+            self._search_task.add_done_callback(self._handle_search_task)
 
     async def _search(self, query):
         self._results_callback(())
         self._searching_callback(True)
-        await self._delay()
+        # TODO: Disabled for now. If this doesn't cause any issues, _delay()
+        #       below should be removed. Remember to also remove the disabled
+        #       tests!
+        # await self._delay()
         results = ()
         try:
             results = await self._search_coro(query)
@@ -278,15 +284,16 @@ class _Searcher:
             self._searching_callback(False)
             self._results_callback(results)
 
-    _min_seconds_between_searches = 1
+    # _min_seconds_between_searches = 1
 
-    async def _delay(self):
-        cur_time = time_monotonic()
-        time_since_prev_search = cur_time - self._previous_search_time
-        if time_since_prev_search <= self._min_seconds_between_searches:
-            remaining_delay = self._min_seconds_between_searches - time_since_prev_search
-            await asyncio.sleep(remaining_delay)
-        self._previous_search_time = time_monotonic()
+    # async def _delay(self):
+    #     cur_time = time_monotonic()
+    #     time_since_prev_search = cur_time - self._previous_search_time
+    #     if time_since_prev_search <= self._min_seconds_between_searches:
+    #         remaining_delay = self._min_seconds_between_searches - time_since_prev_search
+    #         _log.debug('... sleeping %s seconds', remaining_delay)
+    #         await asyncio.sleep(remaining_delay)
+    #     self._previous_search_time = time_monotonic()
 
 
 class _InfoUpdater:
