@@ -148,7 +148,7 @@ class MtvTrackerJobs(TrackerJobsBase):
             if self.scene_check_job.is_scene_release:
                 # Use the scene release name. We rely on scene_check_job making sure
                 # that the file/directory name is the correct release name.
-                search_results = await utils.scene.search(self.content_path)
+                search_results = await utils.predbs.MultiPredbApi().search(self.content_path)
                 assert len(search_results) >= 1, search_results
                 return search_results[0]
 
