@@ -7,7 +7,7 @@ of :class:`~.jobs.base.JobBase` instances.
 It is important that the jobs are only instantiated once and the
 :attr:`~.CommandBase.jobs` property doesn't create new jobs every time it is
 accessed. The easiest way to achieve this is with the
-:func:`~functools.cached_property` decorator.
+:func:`functools.cached_property` decorator.
 
 CLI arguments are available as :attr:`~.CommandBase.args` and configuration
 files as :attr:`~.CommandBase.config`. These should be used to create arguments
