@@ -263,7 +263,7 @@ class ConfigFiles(collections.abc.MutableMapping):
 
         for section in sections:
             parentdir = os.path.dirname(self._files[section])
-            os.makedirs(parentdir, exist_ok=True)
+            os.makedirs(parentdir, mode=0o700, exist_ok=True)
             try:
                 with open(self._files[section], 'w') as f:
                     f.write(self._as_ini(section))
