@@ -10,7 +10,10 @@ import io
 import json
 import os
 import pathlib
+import random
+import re
 import time
+import ssl
 
 import httpx
 
@@ -273,11 +276,11 @@ async def _request(
         params={},
         data={},
         files={},
-        follow_redirects=True,
+        auth=None,
         cache=False,
         max_cache_age=float('inf'),
-        auth=None,
         user_agent=False,
+        follow_redirects=True,
         timeout=_default_timeout,
         cookies=None,
         debug_file=None,
@@ -343,11 +346,29 @@ async def _request(
                             headers=response.headers,
                             status_code=response.status_code,
                         )
+
             except httpx.TimeoutException:
                 raise errors.RequestError(f'{url}: Timeout')
+
+            except ssl.SSLError as e:
+                if hasattr(e, 'verify_message'):
+                    # E.g. "certificate has expired"
+                    msg = e.verify_message.capitalize()
+                elif hasattr(e, 'reason'):
+                    # E.g. "CERTIFICATE_VERIFY_FAILED"
+                    msg = e.reason
+                elif e.strerror:
+                    # `strerror` is inherited from OSError and should be None if
+                    # not provided
+                    msg = e.strerror
+                else:
+                    msg = str(e)
+                raise errors.RequestError(f'{url}: {msg}')
+
             except httpx.HTTPError as e:
                 _log.debug(f'Unexpected HTTP error: {e!r}')
                 raise errors.RequestError(f'{url}: {e}')
+
             else:
                 _save_session_cookies(cookies=client.cookies, domain=response.url.host)
                 if cookies and isinstance(cookies, (str, pathlib.Path)):
@@ -593,3 +614,73 @@ def _cache_file(method, url, params={}):
         _get_cache_directory(),
         utils.fs.sanitize_filename(make_filename(method, url, params_str)),
     )
+
+
+DEFAULT_USER_AGENT = 'Mozilla/5.0 (X11; Linux) Gecko/20100101 Firefox'
+USER_AGENT_CACHE_MAX_AGE = 14 * 24 * 60 * 60
+USER_AGENT_SOURCE_URLS = [
+    'https://www.whatismybrowser.com/guides/the-latest-user-agent/firefox',
+]
+
+async def get_popular_user_agent():
+    """
+    Return commonly used user agent
+
+    The most recent user agent is cached for `USER_AGENT_CACHE_MAX_AGE` seconds.
+
+    If no user agent can be acquired, return `DEFAULT_USER_AGENT`.
+    """
+    user_agent = _get_user_agent_from_cache()
+    if user_agent:
+        return user_agent
+
+    for url in USER_AGENT_SOURCE_URLS:
+        user_agent = await _get_user_agent_from_url(url)
+        if user_agent:
+            _log.debug('Got fresh user agent: %r', user_agent)
+            _cache_user_agent(user_agent)
+            return user_agent
+
+    _log.debug('Defaulting to hardcoded user agent: %s', DEFAULT_USER_AGENT)
+    return DEFAULT_USER_AGENT
+
+def _get_user_agent_from_cache():
+    cache_filepath = _get_user_agent_cache_filepath()
+    if os.path.exists(cache_filepath):
+        cache_created = os.stat(cache_filepath).st_mtime
+        _log.debug('user agent cache created: %r', cache_created)
+        cache_age = time.time() - cache_created
+        _log.debug('    user agent cache age: %r', cache_age)
+        _log.debug('user agent cache max age: %r', USER_AGENT_CACHE_MAX_AGE)
+        if cache_age < USER_AGENT_CACHE_MAX_AGE:
+            try:
+                return open(cache_filepath, 'r').read().strip()
+            except OSError as e:
+                _log.debug('Failed to read user agent from %s: %r', cache_filepath, e)
+
+async def _get_user_agent_from_url(url):
+    try:
+        response = await get(url, cache=False, user_agent=False)
+    except errors.RequestError as e:
+        _log.debug('Failed to fetch user agent from %s: %r', url, e)
+    else:
+        user_agents = re.findall(
+            r'>\s*(Mozilla/5\.0\s*.*?Linux.*?\s*Gecko/\d+\s*.*\s*Firefox/[\d\.]+)\s*<',
+            response,
+        )
+        if user_agents:
+            _log.debug('Got user agents from %s:', url)
+            for ua in user_agents:
+                _log.debug(' * %r', ua)
+            return random.choice(user_agents)
+
+def _cache_user_agent(user_agent):
+    cache_filepath = _get_user_agent_cache_filepath()
+    try:
+        with open(cache_filepath, 'w') as f:
+            f.write(user_agent)
+    except OSError as e:
+        _log.debug('Failed to write user agent to %s: %r', cache_filepath, e)
+
+def _get_user_agent_cache_filepath():
+    return os.path.join(_get_cache_directory(), 'user-agent')
