@@ -890,7 +890,7 @@ class ReleaseInfo(collections.abc.MutableMapping):
     def __init__(self, path, strict=False):
         if strict:
             try:
-                utils.scene.assert_not_abbreviated_filename(path)
+                utils.predbs.assert_not_abbreviated_filename(path)
             except errors.SceneAbbreviatedFilenameError as e:
                 raise errors.ContentError(e)
         self._path = str(path)
@@ -971,7 +971,7 @@ class ReleaseInfo(collections.abc.MutableMapping):
             if (
                 'S' in episodes_string
                 and 'E' not in episodes_string
-                and utils.scene.is_abbreviated_filename(path)
+                and utils.predbs.is_abbreviated_filename(path)
             ):
                 filename = fs.basename(path)
                 match = re.search(r'((?i:[SE]\d+)+)', filename)
