@@ -28,8 +28,6 @@ class ImdbApi(WebDbApiBase):
     _url_base = 'https://www.imdb.com'
     _soup_cache = {}
 
-    user_agent = 'Mozilla/5.0 (X11; Linux x86_64; rv:107.0) Gecko/20100101 Firefox/107.0'
-
     async def _get_soup(self, path, params={}):
         cache_id = (path, tuple(sorted(params.items())))
         if cache_id in self._soup_cache:
@@ -37,7 +35,7 @@ class ImdbApi(WebDbApiBase):
         text = await utils.http.get(
             url=f'{self._url_base}/{path}',
             params=params,
-            user_agent=self.user_agent,
+            user_agent=await utils.http.get_popular_user_agent(),
             cache=True,
         )
         self._soup_cache[cache_id] = utils.html.parse(text)
