@@ -32,8 +32,8 @@ class TmdbApi(WebDbApiBase):
         text = await http.get(
             url=f'{self._url_base}/{path.lstrip("/")}',
             params=params,
+            user_agent=await http.get_popular_user_agent(),
             cache=True,
-            user_agent='Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 6.3; Win64; x64)',
         )
         self._soup_cache[cache_id] = html.parse(text)
         return self._soup_cache[cache_id]
@@ -87,8 +87,16 @@ class TmdbApi(WebDbApiBase):
                 tag.clear()
 
             items = soup.find_all('div', class_='card')
-            return [_TmdbSearchResult(soup=item, tmdb_api=self)
-                    for item in items]
+            results = [_TmdbSearchResult(soup=item, tmdb_api=self)
+                       for item in items]
+
+            if query.year is not None:
+                # Filter the search results for the queried year because TMDb is
+                # very smart and returns wrong search results.
+                return [result for result in results
+                        if result.year == query.year]
+            else:
+                return results
 
     _person_url_path_regex = re.compile(r'(/person/\d+[-a-z]+)')
 
