@@ -122,11 +122,6 @@ class TvmazeApi(WebDbApiBase):
         return ()
 
     async def poster_url(self, id, season=None):
-        """
-        Return URL of poster image or `None`
-
-        :param season: Return poster for specific season
-        """
         if id:
             info = {}
             if season:
@@ -138,7 +133,7 @@ class TvmazeApi(WebDbApiBase):
                         break
             if not info:
                 info = await self._get_show(id)
-            return (info.get('image') or {}).get('medium', None)
+            return (info.get('image') or {}).get('original', None)
         return ''
 
     rating_min = 0.0
